import numpy as np    # important before the class definition
class Particle:
    def __init__(self, mass, x, y, z, vx, vy, vz):
        self.mass = mass
        self.x = x
        self.y = y
        self.z = z
        self.vx = vx
        self.vy = vy
        self.vz = vz
    
    def __str__(self):
        return "{0} at ({1:5.2f},{2:5.2f},{3:5.2f})".format(
             self.__class__.__name__, self.x,self.y,self.z)

    def kinetic_energy(self):
        return 0.5 * self.mass * (self.vx ** 2 + 
                                  self.vy ** 2 +
                                  self.vz ** 2)
    
    def distance(self, other):
        return np.sqrt((self.x - other.x) ** 2 +
                       (self.y - other.y) ** 2 +
                       (self.z - other.z) ** 2)
    
    def move(self, dt):
        self.x = self.x + self.vx * dt
        self.y = self.y + self.vy * dt
        self.z = self.z + self.vz * dt
        
class ChargedParticle(Particle):
    
    def __init__(self, mass, x, y, z, vx, vy, vz, charge):
        Particle.__init__(self, mass, x, y, z, vx, vy, vz)
        self.charge = charge
